@@ -3,17 +3,17 @@ package Alien::GSL;
 use strict;
 use warnings;
 
-our $VERSION = 0.03_01;
+our $VERSION = 0.03_02;
 $VERSION = eval $VERSION;
 
 use Carp;
 use Alien::GSL::ConfigData;
-use File::ShareDir 'module_dir';
+use File::ShareDir 'dist_dir';
 use File::chdir;
 
 # if $location eq share_dir then the module was built in share_dir mode 
 
-my $share_dir = (Alien::GSL::ConfigData->config('location') eq 'share_dir') ? module_dir('Alien::GSL') : '';
+my $share_dir = (Alien::GSL::ConfigData->config('location') eq 'share_dir') ? dist_dir('Alien-GSL') : '';
 
 =head1 NAME 
 
@@ -68,6 +68,10 @@ Specify a directory (here C<dir>) to download and build the library. This direct
 
 Specify a location for the temporary (here C</dev/shm/>, the ramdisk on Ubuntu Linux).
 
+=item C<--GSLCheck>
+
+When this flag is given, if GSL is to be built from source, also include C<make check> in the build phase (before C<make install>). Has no effect if GSL is not going to be built from source.
+
 =back
 
 =head1 NO EXPORTS
@@ -237,7 +241,11 @@ sub gsl_cflags {
 
 =item *
 
-Implement C<--GSLCheck> flag to run C<make check> during build.
+Find a better download site for the compiled libraries.
+
+=item *
+
+Build 64 bit libraries.
 
 =item *
 
